export interface ParseData {
    val: number;
    ext: string;
}
/**
 * Takes an HTML width/size string and performs a calcuation against it.  This
 * would be used to dynamically size an attribute for inline styles in a
 * React component (e.g.).  It uses four basic operations (addition, subtraction
 * multiplication, and division).
 *
 * e.g.
 *
 * taking "20px" and doubling its size => calc('20px', '* 2'); // '40px'
 *
 * @param inp {string | number} - the value that will be modified.  This is a
 * number or a string representing a number.
 * @param oper {string} - the operation that will be applied to the text number
 * @return a new string after the simple math operation has been applied.
 */
export declare function calc(inp: string | number, oper: string): string;
/**
 * Takes an input sizing value as a px value and converts it to an
 * equivalent "em" value.  It divides the size of the input value
 * by the given font size.
 * @param inp {string | number} - the value that will be modified.  This is a
 * number or a string representing a number as a "##px" value.
 * @param fontSize=16 {number} - the pixel height of the font used in this
 * calculation.
 * @param precision=3 {number} - the maximum number of decimal places returned
 * by the calculation
 * @return the new "em" conversion value.
 */
export declare function toEM(inp: string | number, fontSize?: number, precision?: number): string;
/**
 * Takes an input sizing value as a px value and converts it to an
 * equivalent "rem" value.  It divides the size of the input value
 * by the given font size.
 * @param inp {string | number} the value that will be modified.  This is a number
 * or a string representing a number as a "##px" value.
 * @param fontSize=16 {number} - the pixel height of the font used in this
 * calculation.
 * @param precision=3 {number} - the maximum number of decimal places returned
 * by the calculation
 * @return the new "rem" conversion value.
 */
export declare function toREM(inp: string | number, fontSize?: number, precision?: number): string;
/**
 * Converts a unit type number (`16px`) to its number counterpart (`16`).  It
 * will check if a number exists.  If the input is not a number, then an
 * exception is thrown.  This function will handle: "em, pc, pt, px, rem"
 * units.
 * @param inp {string} - the unit number string to convert.
 * @return the number component of the unit value.
 */
export declare function unitToNumber(inp: string): number;
export default calc;
